# Generated by Django 4.1.5 on 2023-01-10 13:02

import django.db.models.deletion
from django.db import migrations, models

import quant_candles.models.base


class Migration(migrations.Migration):
    dependencies = [
        ("contenttypes", "0002_remove_content_type_name"),
        ("quant_candles", "0001_initial"),
    ]

    operations = [
        migrations.CreateModel(
            name="CandleReadOnlyData",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                (
                    "timestamp",
                    models.DateTimeField(db_index=True, verbose_name="timestamp"),
                ),
                (
                    "json_data",
                    models.JSONField(
                        decoder=quant_candles.models.base.QuantCandlesDecoder,
                        default=dict,
                        encoder=quant_candles.models.base.QuantCandlesEncoder,
                        verbose_name="json data",
                    ),
                ),
                (
                    "candle_id",
                    models.BigIntegerField(db_index=True, verbose_name="candle"),
                ),
            ],
            options={
                "verbose_name": "candle data",
                "verbose_name_plural": "candle data",
                "db_table": "quant_candles_candle_read_only_data",
                "ordering": ("timestamp",),
            },
        ),
        migrations.CreateModel(
            name="TimeBasedCandle",
            fields=[],
            options={
                "verbose_name": "time based candle",
                "verbose_name_plural": "time based candles",
                "proxy": True,
                "indexes": [],
                "constraints": [],
            },
            bases=("quant_candles.candle",),
        ),
        migrations.RemoveField(
            model_name="candle",
            name="content_type",
        ),
        migrations.RemoveField(
            model_name="candledata",
            name="file_cache",
        ),
        migrations.RemoveField(
            model_name="candledata",
            name="file_data",
        ),
        migrations.RemoveField(
            model_name="candledata",
            name="frequency",
        ),
        migrations.RemoveField(
            model_name="candledata",
            name="json_cache",
        ),
        migrations.AddField(
            model_name="candle",
            name="polymorphic_ctype",
            field=models.ForeignKey(
                editable=False,
                null=True,
                on_delete=django.db.models.deletion.CASCADE,
                related_name="polymorphic_%(app_label)s.%(class)s_set+",
                to="contenttypes.contenttype",
            ),
        ),
        migrations.AlterField(
            model_name="candle",
            name="json_data",
            field=models.JSONField(
                decoder=quant_candles.models.base.QuantCandlesDecoder,
                default=dict,
                encoder=quant_candles.models.base.QuantCandlesEncoder,
                verbose_name="json data",
            ),
        ),
        migrations.AlterField(
            model_name="candledata",
            name="candle",
            field=models.ForeignKey(
                on_delete=django.db.models.deletion.CASCADE,
                to="quant_candles.candle",
                verbose_name="candle",
            ),
        ),
        migrations.AlterField(
            model_name="candledata",
            name="json_data",
            field=models.JSONField(
                decoder=quant_candles.models.base.QuantCandlesDecoder,
                default=dict,
                encoder=quant_candles.models.base.QuantCandlesEncoder,
                verbose_name="json data",
            ),
        ),
        migrations.AlterField(
            model_name="tradedata",
            name="json_data",
            field=models.JSONField(
                decoder=quant_candles.models.base.QuantCandlesDecoder,
                encoder=quant_candles.models.base.QuantCandlesEncoder,
                null=True,
                verbose_name="json data",
            ),
        ),
        migrations.AlterField(
            model_name="tradedata",
            name="symbol",
            field=models.ForeignKey(
                on_delete=django.db.models.deletion.CASCADE,
                related_name="trade_data",
                to="quant_candles.symbol",
            ),
        ),
        migrations.CreateModel(
            name="CandleCache",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                (
                    "timestamp",
                    models.DateTimeField(db_index=True, verbose_name="timestamp"),
                ),
                (
                    "frequency",
                    models.PositiveIntegerField(
                        choices=[
                            (1, "Minute"),
                            (60, "Hour"),
                            (1440, "Day"),
                            (10080, "Week"),
                        ],
                        db_index=True,
                        verbose_name="frequency",
                    ),
                ),
                (
                    "json_data",
                    models.JSONField(
                        decoder=quant_candles.models.base.QuantCandlesDecoder,
                        encoder=quant_candles.models.base.QuantCandlesEncoder,
                        null=True,
                        verbose_name="json data",
                    ),
                ),
                (
                    "candle",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="data",
                        to="quant_candles.candle",
                    ),
                ),
            ],
            options={
                "verbose_name": "candle cache",
                "verbose_name_plural": "candle cache",
                "db_table": "quant_candles_candle_cache",
                "ordering": ("timestamp",),
            },
        ),
        migrations.CreateModel(
            name="TradeDataSummary",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("date", models.DateField(db_index=True, verbose_name="date")),
                (
                    "file_data",
                    models.FileField(
                        blank=True,
                        upload_to=quant_candles.models.trades.upload_trade_data_summary_to,
                        verbose_name="file data",
                    ),
                ),
                (
                    "json_data",
                    models.JSONField(
                        decoder=quant_candles.models.base.QuantCandlesDecoder,
                        encoder=quant_candles.models.base.QuantCandlesEncoder,
                        null=True,
                        verbose_name="json data",
                    ),
                ),
                (
                    "symbol",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="trade_data_summary",
                        to="quant_candles.symbol",
                    ),
                ),
            ],
            options={
                "verbose_name": "trade data summary",
                "verbose_name_plural": "trade data summary",
                "db_table": "quant_candles_trade_data_summary",
                "ordering": ("date",),
            },
        ),
    ]
